@@ -17,6 +17,7 @@ use tokio_rustls::rustls::{self, ServerConfig};
 /// Issues certificates for communicating with clients over TLS. Certificates are cached in memory
 /// up to a max size that is provided when creating the authority. Certificates are generated using
 /// the `openssl` crate.
+#[cfg_attr(docsrs, doc(cfg(feature = "openssl-certs")))]
 #[derive(Clone)]
 pub struct OpensslAuthority {
     pkey: PKey<Private>,
@@ -78,13 +79,19 @@ impl CertificateAuthority for OpensslAuthority {
             .gen_cert(authority)
             .unwrap_or_else(|_| panic!("Failed to generate certificate for {}", authority))];
 
-        let server_cfg = Arc::new(
-            ServerConfig::builder()
-                .with_safe_defaults()
-                .with_no_client_auth()
-                .with_single_cert(certs, self.private_key.clone())
-                .expect("Failed to build ServerConfig"),
-        );
+        let mut server_cfg = ServerConfig::builder()
+            .with_safe_defaults()
+            .with_no_client_auth()
+            .with_single_cert(certs, self.private_key.clone())
+            .expect("Failed to build ServerConfig");
+
+        server_cfg.alpn_protocols = vec![
+            #[cfg(feature = "http2")]
+            b"h2".to_vec(),
+            b"http/1.1".to_vec(),
+        ];
+
+        let server_cfg = Arc::new(server_cfg);
 
         self.cache
             .insert(authority.clone(), Arc::clone(&server_cfg))
